@@ -1,8 +1,11 @@
 /* Python header files. */
 
-#include <Python.h>
-#include <datetime.h>
-#include <structmember.h>
+#include "Python.h"
+
+#include "datetime.h"
+#include "structmember.h"
+
+/* The libastro header files. */
 
 #include "astro.h"
 #include "preferences.h"
@@ -165,7 +168,7 @@ static int copy_planet_from_builtin(Planet *planet, int builtin_index)
    like 'hours:minutes:seconds' or 'degrees:minutes:seconds',
    depending on the factor given it. */
 
-staticforward PyTypeObject AngleType;
+static PyTypeObject AngleType;
 
 typedef struct {
      PyFloatObject f;
@@ -312,7 +315,7 @@ static PyTypeObject AngleType = {
    supports triple() and tuple() methods for extracting its date and
    time components. */
 
-staticforward PyTypeObject DateType;
+static PyTypeObject DateType;
 
 typedef PyFloatObject DateObject;
 
@@ -328,42 +331,49 @@ static int parse_mjd_from_string(PyObject *so, double *mjdp)
      PyObject *split_func = PyObject_GetAttrString(so, "split");
      PyObject *pieces = PyObject_Call(split_func, emptytuple, 0);
      int len = PyObject_Length(pieces);
-     char *s = (len >= 1) ? PyString_AsString(PyList_GetItem(pieces, 0)) : 0;
-     char *t = (len >= 2) ? PyString_AsString(PyList_GetItem(pieces, 1)) : 0;
      int year, month = 1;
      double day = 1.0;
 
      Py_DECREF(emptytuple);
      Py_DECREF(split_func);
-     Py_DECREF(pieces);
 
      if ((len < 1) || (len > 2))
 	  goto fail;
 
-     if (s) {
+     if (len >= 1) {
+          char *s = PyString_AsString(PyList_GetItem(pieces, 0));
+          if (!s) goto fail;
+
 	  /* Make sure all characters are in set '-/.0123456789' */
 
 	  int i;
-	  for (i=0; s[i]; i++)
+	  for (i=0; s[i]; i++) {
 	       if (s[i] != '-' && s[i] != '/' && s[i] != '.'
-		   && (s[i] < '0' || s[i] > '9'))
+		   && (s[i] < '0' || s[i] > '9')) {
 		    goto fail;
+               }
+          }
 
 	  f_sscandate(s, PREF_YMD, &month, &day, &year);
      }
 
-     if (t) {
+     if (len >= 2) {
+          char *t = PyString_AsString(PyList_GetItem(pieces, 1));
 	  double hours;
-	  if (f_scansexa(t, &hours) == -1)
+          if (!t) goto fail;
+	  if (f_scansexa(t, &hours) == -1) {
 	       goto fail;
+          }
 	  day += hours / 24.;
      }
 
      cal_mjd(month, day, year, mjdp);
+
+     Py_DECREF(pieces);
      return 0;
 
 fail:
-     {
+     if (! PyErr_Occurred()) {
 	  PyObject *repr = PyObject_Repr(so);
           PyObject *complaint = PyString_FromFormat(
 	       "your date string %s does not look like a year/month/day"
@@ -373,6 +383,7 @@ fail:
 	  Py_DECREF(repr);
 	  Py_DECREF(complaint);
      }
+     Py_DECREF(pieces);
      return -1;
 }
 
@@ -586,12 +597,8 @@ static int parse_angle(PyObject *value, double factor, double *result)
      } else if (PyString_Check(value)) {
 	  double scaled;
 	  char *s = PyString_AsString(value);
-	  char *sc;
-	  for (sc=s; *sc && *sc != ':' && *sc != '.'; sc++) ;
-	  if (*sc == ':')
-	       f_scansexa(s, &scaled);
-	  else
-	       scaled = atof(s);
+          if (!s) return -1;
+          f_scansexa(s, &scaled);
 	  *result = scaled / factor;
 	  return 0;
      } else {
@@ -616,12 +623,12 @@ static double to_angle(PyObject *value, double efactor, int *status)
 	  return r;
      } else if (PyString_Check(value)) {
 	  double scaled;
-	  char *sc, *s = PyString_AsString(value);
-	  for (sc=s; *sc && *sc != ':' && *sc != '.'; sc++) ;
-	  if (*sc == ':')
-	       f_scansexa(s, &scaled);
-	  else
-	       scaled = atof(s);
+          char *s = PyString_AsString(value);
+          if (!s) {
+               *status = -1;
+               return 0;
+          }
+          f_scansexa(s, &scaled);
 	  *status = 0;
 	  return scaled / efactor;
      } else {
@@ -1016,12 +1023,12 @@ static PyTypeObject ObserverType = {
  *
  */
 
-staticforward PyTypeObject BodyType;
-staticforward PyTypeObject PlanetType;
-staticforward PyTypeObject JupiterType;
-staticforward PyTypeObject SaturnType;
-staticforward PyTypeObject MoonType;
-staticforward PyTypeObject PlanetMoonType;
+static PyTypeObject BodyType;
+static PyTypeObject PlanetType;
+static PyTypeObject JupiterType;
+static PyTypeObject SaturnType;
+static PyTypeObject MoonType;
+static PyTypeObject PlanetMoonType;
 
 static PyObject* Body_compute(PyObject *self, PyObject *args, PyObject *kwds);
 
@@ -2554,12 +2561,14 @@ static PyObject* readdb(PyObject *self, PyObject *args)
 
 static PyObject* readtle(PyObject *self, PyObject *args)
 {
-     char *l1, *l2;
+     char *l0, *l1, *l2;
      PyObject *name, *stripped_name, *body, *catalog_number;
      Obj obj;
      if (!PyArg_ParseTuple(args, "O!ss:readtle",
 			   &PyString_Type, &name, &l1, &l2))
 	  return 0;
+     l0 = PyString_AsString(name);
+     if (!l0) return 0;
      if (db_tle(PyString_AsString(name), l1, l2, &obj)) {
 	  PyErr_SetString(PyExc_ValueError,
 			  "line does not conform to tle format");
@@ -2813,6 +2822,69 @@ static PyObject *my_precess(PyObject *self, PyObject *args)
      return Py_BuildValue("(OO)", build_hours(ra), build_degrees(dec));
 }
 
+static PyObject *_next_pass(PyObject *self, PyObject *args)
+{
+     Observer *observer;
+     Body *body;
+     RiseSet rs;
+     if (!PyArg_ParseTuple(args, "O!O!", &ObserverType, &observer,
+                           &BodyType, &body))
+          return 0;
+     riset_cir(& observer->now, & body->obj, - body->now.n_dip, & rs);
+     if (rs.rs_flags & RS_CIRCUMPOLAR) {
+          PyErr_SetString(PyExc_ValueError, "that satellite appears to be"
+                          " circumpolar and so will never cross the horizon");
+          return 0;
+     }
+     if (rs.rs_flags & RS_NEVERUP) {
+          PyErr_SetString(PyExc_ValueError, "that satellite seems to stay"
+                          " always below your horizon");
+          return 0;
+     }
+     if (rs.rs_flags & RS_ERROR) {
+          PyErr_SetString(PyExc_ValueError, "cannot find when that"
+                          " satellite next crosses the horizon");
+          return 0;
+     }
+     {
+          PyObject *risetm, *riseaz, *trantm, *tranalt, *settm, *setaz;
+
+          if (rs.rs_flags & RS_NORISE) {
+               Py_INCREF(Py_None);
+               risetm = Py_None;
+               Py_INCREF(Py_None);
+               riseaz = Py_None;
+          } else {
+               risetm = build_Date(rs.rs_risetm);
+               riseaz = build_degrees(rs.rs_riseaz);
+          }
+
+          if (rs.rs_flags & RS_NOTRANS) {
+               Py_INCREF(Py_None);
+               trantm = Py_None;
+               Py_INCREF(Py_None);
+               tranalt = Py_None;
+          } else {
+               trantm = build_Date(rs.rs_trantm);
+               tranalt = build_degrees(rs.rs_tranalt);
+          }
+
+          if (rs.rs_flags & RS_NOSET) {
+               Py_INCREF(Py_None);
+               settm = Py_None;
+               Py_INCREF(Py_None);
+               setaz = Py_None;
+          } else {
+               settm = build_Date(rs.rs_settm);
+               setaz = build_degrees(rs.rs_setaz);
+          }
+
+          return Py_BuildValue(
+               "(OOOOOO)", risetm, riseaz, trantm, tranalt, settm, setaz
+               );
+     }
+}
+
 /*
  * The global methods table and the module initialization function.
  */
@@ -2864,6 +2936,11 @@ static PyMethodDef libastro_methods[] = {
 
      {"builtin_planets", (PyCFunction) builtin_planets, METH_NOARGS,
       "return the list of built-in planet objects"},
+
+     {"_next_pass", (PyCFunction) _next_pass, METH_VARARGS,
+      "Return as a tuple the next rising, culmination, and setting"
+      " of an EarthSatellite"},
+
      {NULL}
 };
 
