@@ -7,8 +7,9 @@
  *   See http://www.celestrak.com/NORAD/documentation/spacetrk.pdf.
  *
  * A few topocentric routines are also used from the 'orbit' program which is
- *   Copyright (c) 1986,1987,1988,1989,1990 Robert W. Berger N3EMO
- *
+ *   Copyright (c) 1986,1987,1988,1989,1990 Robert W. Berger N3EMO, who has
+ *   granted permission for it to be licensed under the same terms as those
+ *   of the PyEphem package in which this source file is included.
  */
 
 /* define this to use orbit's propagator
@@ -236,7 +237,7 @@ obj_earthsat (Now *np, Obj *op)
 	/* find s_ra/dec, depending on current options. */
 	if (pref_get(PREF_EQUATORIAL) == PREF_TOPO) {
 	    double ha, lst;
-	    aa_hadec (lat, (double)op->s_alt, (double)op->s_az, &ha, &dec);
+	    aa_hadec (lat, Elevation, (double)op->s_az, &ha, &dec);
 	    now_lst (np, &lst);
 	    ra = hrrad(lst) - ha;
 	    range (&ra, 2*PI);
@@ -788,4 +789,4 @@ InitOrbitRoutines(double EpochDay, int AtEod)
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: earthsat.c,v $ $Date: 2004/10/06 21:56:25 $ $Revision: 1.9 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: earthsat.c,v $ $Date: 2007/05/09 03:19:29 $ $Revision: 1.10 $ $Name:  $"};
