@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 import sys, warnings
 from sets import Set
@@ -20,6 +21,8 @@ attribute_list = (
      ('hlong', 'hlat', 'sun_distance', 'earth_distance', 'phase')),
     (Moon, False,
      ('colong', 'subsolar_lat', 'libration_lat', 'libration_long')),
+    (Jupiter, False,
+     ('cmlI', 'cmlII')),
     (Saturn, False,
      ('earth_tilt', 'sun_tilt')),
     (PlanetMoon, False,
@@ -238,6 +241,32 @@ class body_suite(MyTestCase):
                         '_n': 14.99359833, '_orbit': 59452,
                         })
 
+    def test_newlineTLE(self):
+        """Make sure TLE strings with newlines are accepted."""
+        # based on bug report from Reto Schüttel, 2008 Dec 10
+        readtle('HST                     \n',
+                '1 20580U 90037B   04296.45910607  .00000912 '
+                ' 00000-0  59688-4 0  1902\n',
+                '2 20580  28.4694  17.3953 0004117 265.2946  '
+                '94.7172 14.99359833594524\n')
+
+# A user reported that Saturn's ring tilt was misbehaving, and there was
+# indeed a major error occuring in its calculation.  This small test
+# should assure that reasonable values are returned from now on.
+
+class planet_suite(unittest.TestCase):
+    """See whether Jupiter Central Meridian Longitudes look good."""
+    def test_jupiter(self):
+        j = Jupiter('2008/10/1')
+        self.assertEqual(str(j.cmlI), '146:15:13.8')
+        self.assertEqual(str(j.cmlII), '221:03:27.0')
+
+    """Check the tilt of Saturn's rings."""
+    def test_saturn(self):
+        s = Saturn('2008/10/1')
+        assert -0.07 < s.earth_tilt < -0.06
+        assert -0.09 < s.sun_tilt < -0.08
+
 # Make sure the constellation function forces objects to determine
 # their position before using their right ascension and declination.
 
