@@ -6,6 +6,13 @@ from datetime import datetime
 from time import strptime
 import ephem
 
+# Since users might be in another locale, we have to translate the
+# month into an integer on our own.
+month_ints = {
+    'Jan': 1, 'Feb': 2, 'Mar': 3, 'Apr': 4, 'May': 5, 'Jun': 6,
+    'Jul': 7, 'Aug': 8, 'Sep': 9, 'Oct': 10, 'Nov': 11, 'Dec': 12,
+    }
+
 # Read an ephemeris from the United States Naval Observatory, and
 # confirm that PyEphem returns the same measurements to within one
 # arcsecond of accuracy.
@@ -39,11 +46,14 @@ def standard_parse(line):
     """Read the date, RA, and dec from a USNO data file line."""
 
     fields = re.split(r'   +', line)
-    dt = datetime(*strptime(fields[0][:-2], "%Y %b %d %H:%M:%S")[0:6])
+    datestrfields = fields[0][:-2].split()
+    datestrfields[1] = str(month_ints[datestrfields[1]])
+    datestr = ' '.join(datestrfields)
+    dt = datetime(*strptime(datestr, "%Y %m %d %H:%M:%S")[0:6])
     date = ephem.Date(dt)
-    ra = ephem.hours(fields[1].replace(' ', ':'))
+    ra = ephem.hours(':'.join(fields[1].split()))
     sign, mag = fields[2].split(None, 1)
-    dec = ephem.degrees(sign + mag.replace(' ', ':'))
+    dec = ephem.degrees(sign + ':'.join(mag.split()))
     return date, ra, dec
 
 def is_near(n, m, error = ephem.arcsecond):
@@ -208,8 +218,9 @@ The file looks something like:
         """
         datum = Datum()
         fields = line.split()
+        fields[1] = str(month_ints[fields[1]])
 
-        dt = datetime(*strptime(' '.join(fields[0:3]), "%Y %b %d")[0:3])
+        dt = datetime(*strptime(' '.join(fields[0:3]), "%Y %m %d")[0:3])
         midnight = ephem.Date(ephem.Date(dt) - self.tz)
         datum.midnight = midnight
 
@@ -429,8 +440,11 @@ class Moon_Phases(Trial):
                 self.verify(func, datestr)
 
     def verify(self, func, datestr):
+        datestrfields = datestr.split()
+        datestrfields[0] = str(month_ints[datestrfields[0]])
+        datestr = ' '.join(datestrfields)
         dt = datetime(*strptime('%d %s' % (self.year, datestr),
-                                "%Y %b %d %H %M")[0:5])
+                                "%Y %m %d %H %M")[0:5])
         date = ephem.Date(dt)
         self.date = func(self.date) # advance to next phase
         is_near(date, self.date, ephem.minute)
